@@ -1,5 +1,5 @@
 mln.objective <-
-function(theta, r, y, te, s0, market.calls, call.strikes, market.puts, put.strikes, lambda = 1)
+function(theta, r, y, te, s0, market.calls, call.strikes, call.weights=1, market.puts, put.strikes, put.weights=1, lambda = 1)
 {
   alpha.1     = theta[1]
   meanlog.1   = theta[2] 
@@ -15,14 +15,14 @@ function(theta, r, y, te, s0, market.calls, call.strikes, market.puts, put.strik
   ### Calls
   ###
 
-  theoretical.calls = mln.option.price(r = r, te = te, y = y, k = call.strikes, alpha.1 = alpha.1, 
+  theoretical.calls = price.mln.option(r = r, te = te, y = y, k = call.strikes, alpha.1 = alpha.1, 
                                        meanlog.1 = meanlog.1, meanlog.2 = meanlog.2, sdlog.1 = sdlog.1, sdlog.2 = sdlog.2)$call
 
   ###
   ### puts
   ###
 
-  theoretical.puts = mln.option.price(r = r, te = te, y = y, k = put.strikes, alpha.1 = alpha.1, 
+  theoretical.puts = price.mln.option(r = r, te = te, y = y, k = put.strikes, alpha.1 = alpha.1, 
                                        meanlog.1 = meanlog.1, meanlog.2 = meanlog.2, sdlog.1 = sdlog.1, sdlog.2 = sdlog.2)$put
 
 
@@ -30,7 +30,7 @@ function(theta, r, y, te, s0, market.calls, call.strikes, market.puts, put.strik
   ### Finally ... the objective function
   ###
 
-  if ( (alpha.1 < 0) | (alpha.1 > 1) | (sdlog.1 < 0) | (sdlog.2 < 0) ) {obj = 10^7} else { obj = sum((theoretical.calls - market.calls)^2) + sum((theoretical.puts - market.puts)^2) + lambda * (s0*exp(-y*te) - expected.value * discount.factor )^2 }
+  if ( (alpha.1 < 0) | (alpha.1 > 1) | (sdlog.1 < 0) | (sdlog.2 < 0) ) {obj = 10^7} else { obj = sum(call.weights * (theoretical.calls - market.calls)^2) + sum(put.weights*(theoretical.puts - market.puts)^2) + lambda * (s0 - exp(y*te) * expected.value * discount.factor )^2 }
   obj
 
 }
